#! /usr/bin/env bash

function print_usage_and_exit {
  >&2 echo "USAGE : (tsv | txt) expPath [arguments]"
  exit 1
}

MODE=$1
EXPPATH=$2

>&2 echo "********************************************************************************"
>&2 echo "Training : "$EXPPATH

if [ -z "$MODE" ];
then
  >&2 echo "ERROR : missing argument 1 (mode)"
  print_usage_and_exit
fi

if [ -z "$EXPPATH" ];
then
  >&2 echo "ERROR : missing argument 2 (expPath)"
  print_usage_and_exit
fi

shift
shift

if [ ! -d "$EXPPATH" ]; then
  >&2 echo "ERROR : directory $EXPPATH doesn't exist"
  print_usage_and_exit
fi

TARGET="all_text"
if [[ "$*" == *--lineByLine* ]]
then
  TARGET="all_lines"
fi

CURDIR=$(pwd)
cd $EXPPATH"/"data && make -s clean && make $TARGET -s
cd $CURDIR

TRAIN=$EXPPATH"/data/train.conllu"
TRAINRAW=$EXPPATH"/data/train.txt"
DEV=$EXPPATH"/data/dev.conllu"
DEVRAW=$EXPPATH"/data/dev.txt"
TEST=$EXPPATH"/data/test.conllu"
TESTRAW=$EXPPATH"/data/test.txt"

if test ! -f $TRAIN;
then
  pwd
  >&2 echo "ERROR : no train file found in" $EXPPATH
  >&2 echo "$TRAIN"
  print_usage_and_exit
fi

if test ! -f $DEV;
then
	DEV=""
fi

if [ "$MODE" = "txt" ]; then
	if test ! -f $TRAINRAW;
	then
	  >&2 echo "ERROR : no train file found in" $EXPPATH
	  >&2 echo "$TRAINRAW"
	  print_usage_and_exit
	fi
	if test ! -f $DEVRAW;
	then
		DEVRAW=""
	fi
fi

if [ "$MODE" = "tsv" ]; then
macaon train --model $EXPPATH --trainTSV $TRAIN --devTSV $DEV "$@" || exit 1
exit 0
fi

if [ "$MODE" = "txt" ]; then
macaon train --model $EXPPATH --trainTSV $TRAIN --trainTXT $TRAINRAW --devTSV $DEV --devTXT $DEVRAW "$@" || exit 1
exit 0
fi

print_usage_and_exit

